import{_ as e,n as s,h as l,T as o}from"./c.1ff2516f.js";import"./c.20fae408.js";import"./index-9fb59a6d.js";let a=class extends l{render(){return o`
      <esphome-process-dialog
        heading="Update All"
        .type=${"update-all"}
        @closed=${this._handleClose}
      ></esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};a=e([s("esphome-update-all-dialog")],a);
